@@ -4,8 +4,6 @@
 #define SHIBARI_H
 
 #include <shibari/common.h>
-#include <shibari/client.h>
-#include <shibari/cache.h>
 #include <shibari/server.h>
 
 #endif
